@@ -11,22 +11,22 @@ from django.utils import regex_helper, simplejson
 from pushserver import signals
 from pushserver.utils import urllib
 
+# Set by runpushserver command
+# Using this host fails if it is bind-all address (eg. 0.0.0.0),
+# in this case settings should be manually configured
+current_host = None
+
 def publisher_url(channel):
     push_server = getattr(settings, 'PUSH_SERVER', {})
-    port = push_server.get('port', None)
+    publisher_host = push_server.get('publisher_host', current_host)
     publisher_pattern = None
     for location in push_server.get('locations', ()):
         if location.get('type') == 'publisher':
             publisher_pattern = location.get('url')
             # TODO: Currently we support only the first publisher URL
             break
-    address = push_server.get('address')
-    if not address or not publisher_pattern or port is None:
+    if not publisher_host or not publisher_pattern:
         raise ValueError("Missing required settings")
-    if port == 80:
-        port = ''
-    else:
-        port = ':%s' % (port,)
     publisher = regex_helper.normalize(publisher_pattern)
     if len(publisher) != 1 or len(publisher[0][1]) != 1:
         raise ValueError("Non-reversible reg-exp: '%s'" % (publisher_pattern,))
@@ -34,24 +34,19 @@ def publisher_url(channel):
     publisher = publisher % {
         arg: channel,
     }
-    return 'http://%s%s%s' % (address, port, publisher)
+    return 'http://%s%s' % (publisher_host, publisher)
 
 def subscriber_url(channel):
     push_server = getattr(settings, 'PUSH_SERVER', {})
-    port = push_server.get('port', None)
+    subscriber_host = push_server.get('subscriber_host', current_host)
     subscriber_pattern = None
     for location in push_server.get('locations', ()):
         if location.get('type') == 'subscriber':
             subscriber_pattern = location.get('url')
             # TODO: Currently we support only the first subscriber URL
             break
-    address = push_server.get('address')
-    if not address or not subscriber_pattern or port is None:
+    if not subscriber_host or not subscriber_pattern:
         raise ValueError("Missing required settings")
-    if port == 80:
-        port = ''
-    else:
-        port = ':%s' % (port,)
     subscriber = regex_helper.normalize(subscriber_pattern)
     if len(subscriber) != 1 or len(subscriber[0][1]) != 1:
         raise ValueError("Non-reversible reg-exp: '%s'" % (subscriber_pattern,))
@@ -59,7 +54,7 @@ def subscriber_url(channel):
     subscriber = subscriber % {
         arg: channel,
     }
-    return 'http://%s%s%s' % (address, port, subscriber)
+    return 'http://%s%s' % (subscriber_host, subscriber)
 
 def send_update(channel_id, data, already_serialized=False, ignore_errors=False):
     if already_serialized:
